@@ -1,21 +1,23 @@
 .onAttach <- function(lib, pkg){
   # Test for features
-  testfor <- c("cairo", "fontconfig", "freetype", "fftw", "ghostscript", "lcms", "pango", "rsvg", "webp", "x11")
+  testfor <- c("cairo", "fontconfig", "freetype", "fftw", "ghostscript", "heic", "lcms", "pango", "raw", "rsvg", "webp", "x11")
   support <- unlist(magick_config()[testfor])
   has <- paste(names(which(support)), collapse = ", ")
   not <- paste(names(which(!support)), collapse = ", ")
-
+  threads <- magick_threads(0)
   packageStartupMessage(sprintf("Linking to ImageMagick %s\nEnabled features: %s\nDisabled features: %s",
                                 as.character(magick_config()$version), has, not))
+  if(isTRUE(threads > 1))
+    packageStartupMessage(sprintf("Using %d threads", threads))
 
   # For RStudio
   autoviewer_enable()
 }
 
 .onLoad <- function(lib, pkg){
-  if(is_check()){
-    # Try to please cran...
-    Sys.setenv(OMP_THREAD_LIMIT = 1, MAGICK_THREAD_LIMIT = 1)
+  # Try to please cran...
+  if(is_check() && isTRUE(magick_threads() > 2)){
+    magick_threads(2)
   }
 
   # Set tempdir to R session
